##  Overview
You can configure SAP LeanIX to access SAP BTP, Cloud Foundry by using trusted certificate authentication with X.509 client certificates in SAP Cloud Identity Services – Identity Authentication (IAS). Use this procedure if you cannot use, or do not want to use, user certificate authentication, as described in [SAP BTP, Cloud Foundry Integration for SAP Discovery](https://help.sap.com/docs/leanix/ea/configuring-sap-btp-cloud-foundry-integration?locale=en-US&state=PRODUCTION&version=CLOUD "Connect your SAP BTP, Cloud Foundry environment to SAP LeanIX to improve the visibility of self-built applications within your enterprise architecture.").
To connect LeanIX to SAP BTP, Cloud Foundry with trusted certificate authentication, complete the following steps:
  * Create or confirm the IAS platform user for LeanIX.
  * Enable trusted certificate authentication in IAS, and disable user certificate authentication.
  * Configure the SAP BTP, Cloud Foundry integration in LeanIX to use X.509 certificates matched by a certificate pattern.
  * Copy the certificate pattern generated by LeanIX into the trusted certificate configuration in IAS.
